/**
 * Copyright (c) 2012-2015 Net-ng.
 * All rights reserved.
 *
 * This software is licensed under the BSD License, as described in
 * the file LICENSE.txt, which you should have received as part of
 * this distribution.
 **/

.success {
    font-size: 15px;
    padding: 10px 0;
}

.success i {
    color: #93B70A;
    margin-right: 5px;
    font-size: 20px;
}

.huge {
    font-size: 100px;
    line-height: 200px;
}

#calendar .fc-view-container {
    background: #eaeaea;
}

/* Board */
.board .board-title {
    color: inherit;
    font: normal 33px OpenSansSemibold;
}

.board .board-title a {
    color: inherit;
    text-decoration: none;
}

.board .board-title a:hover {
    color: inherit;
    text-decoration: none;
}


.board .board-title .title-form {
    font-size: 24px;
}

.board-title-color {
    border-radius: 3px;
    background-color: inherit;
    border: 1px solid #737373;
    vertical-align: middle;
}

/* End board */

/* Lists */

.list {
    border-radius: 3px;
    border: 1px solid #d8d8d8;
    background:  rgba(229, 229, 229, 0.9);
}

.archive {
    background: #d8d8d8;
}

.list.reduced .list-header {
    border-bottom: 1px solid #EAEAEA;
}

.list-header {
    border-radius: 5px 5px 0 0;
}

.list-actions i {
    color: inherit;
}

.list-header .title {
    font-size: 18px;
    font-family: OpenSansRegular;
    color: #434343;
}

.list-header .title a,
.list .header .title a:hover,
.list .header .title a:visited {
    color: inherit;
    text-decoration: none;
}

.list .list-footer {
    border-top: 1px solid #d8d8d8;
    border-radius: 0 0 5px 5px;
    background: #e5e5e5;
}

.list .list-footer-disabled {
    border-radius: 0 0 5px 5px;
    border-top: solid 1px #c0c0c0;
    background: #d8d8d8;
}

.list .list-footer:hover {
    background: #d8d8d8;
}

.list .list-footer .link-small {
    color: inherit;
    font-size: 15px;
}

.list .list-footer .link-small:hover {
    text-decoration: none;
}

.list .list-footer .link-small strong {
    color: #939393;
    font-size: 22px;
}

.list-marker {
	margin: 0px 0 0 10px;
}

.list .nav-list li a:hover {
    color: #333;
}


/* End lists */

/* Cards */
.card:hover {
    box-shadow: #a7a7a7 1px 1px 1px
}

.card {
    background-color: white;
    border-radius: 3px;
}

.card > div > a {
    color: #434343;
}

.card.highlight {
    border: solid 2px #e6a323;
}

/* Card drag n drop */
.card-dragging {
    -moz-transform: rotate(2deg);
    -ms-transform: rotate(2deg);
    -webkit-transform: rotate(2deg);
    -o-transform: rotate(2deg);
    transform: rotate(2deg);
}

.card-dragging .card {
    border: 1px solid #d8d8d8;
}

/* DnD drop targets */
.card-marker,
.list-marker,
.checklists .ui-state-highlight, .checklists .checklist .ui-state-highlight {
    border-radius: 3px;
    border: 1px solid #c8c8c8;
    background-color: #dfdcdc;
    box-shadow: inset #b5b5b5 2px 1px 1px;
}

/* End card drag n drop */

/* Editor */
.description-content a {
    color: #009fed;
    text-decoration: underline;
}

.card-edit-form .header,
.card-edit-form .header a,
.card-edit-form .header a:hover {
    text-decoration: none;
}

.card-edit-form .header .in-list {
    font-size: 18px;
    font-family: OpenSansLightItalic;
    color: inherit;
}

.card-edit-form .header .title-form {
    font-size: 14px;
}

.card-edit-form .header .title {
    font-size: 30px;
    color: inherit;
}

.card-edit-form .header .title a {
    color: #737373
}

.wysihtml-command-active, .wysihtml-command-dialog-opened {
    border: 1px solid #c0c0c0;
}


.editor-popin {
    background: white;
}


/* End editor */

/* Badges */
.badge {
    color: #a5a5a5;
}

.badge i {
    font-size: 13px;
}

.badge > .label {
    font-size: 12px;
}

/* End badges */

/* Card overlays */
.overlay.card-overlay {
    color: inherit;
}

.overlay.card-overlay h2 {
    border-bottom: 1px solid #eaeaea;
    color: inherit;
    font-size: 17px;
    font-weight: normal;
}

.overlay.card-overlay .member .actions .btn {
    font-size: 12px;
}

.overlay.card-overlay .name {
    font-size: 14px;
    color: inherit;
}

.overlay.card-overlay .name .email {
    font-size: 11px;
    font-style: italic;
}

i.ico-btn.icon-user-plus {
    font-size: 23px;
}

/* End card overlays */

/* Card counter */
.cardCounter {
    font-size: 12px;
    background: #737373;
    color: #eaeaea;
    border-radius: 5px;
}

.cardCounter a {
    color: #eaeaea;
}

.limitReached {
    background: #c22e2e;
}

.max-weight-highlight .limitReached {
    background-color: #e6a323;
}

.list-header .list-counter .nagare-error-message:before {
    border-bottom: 7px solid rgba(0, 0, 0, 0.1);
    border-left: 7px solid transparent;
    border-right: 7px solid transparent;
}

.list-header .list-counter .nagare-error-message:after {
    border-bottom: 6px solid white;
    border-left: 6px solid transparent;
    border-right: 6px solid transparent;
}

.list-header .list-counter .nagare-error-message {
    border-radius: 5px;
    border: 1px solid #c0c0c0;
    background: white url("../../../img/warning.png") no-repeat left center;
}
/* End card counter */

/* Comments */
.comment .date {
    font-size: 11px;
}

.comment .fullname {
    font-weight: bold;
}

.comment .contents img.medium {
    border: 4px solid white;
}

.comment:last-child .right {
    border: 0
}

.comment .user.fullname {
    font-weight: bold;
}

.comment .footer {
    font-size: 90%;
}

.comment-delete {
    display: none;
    float: right;
}

.comment:hover .comment-delete {
    display: inline-block;
}

/* End comments */

/* Labels */

.card-label > span {
    color: white;
}

a.card-label:hover {
    text-decoration: none;
}

.card-label {
    border-radius: 14px;
    border: 2px solid white;
    box-shadow: 3px 1px 1px #D6D6D6;
}

.editable-labels .card-label {
    border-radius: 17px;
}

.editable-labels .inactive:before {
    border-radius: 17px;
}

.label-color-picker .yui-picker-controls .bd {
    background-color: inherit;
}

/* End label */

/* Due dates */
.due-date span {
    font-size: 10px;
    color: white
}

.due-date.past,
.btn-due-date.past{
    color: #737373 !important;
}

.due-date.yesterday,
.btn-due-date.yesterday {
    color: #A01A00 !important;
}

.due-date.today,
.btn-due-date.today{
    color: #c22e2e !important;
}

.due-date.tomorrow,
.btn-due-date.tomorrow{
    color: #e6a323 !important;
}

.due-date.future,
.btn-due-date.future{
    color: #93b70a !important;
}
/* End due dates */

/* Card gallery */
#card-gallery .asset {
    border: 4px solid white;
    box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.24);
    margin: 8px 6px 0 0;
}

#card-gallery .asset:hover {
    box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.64)
}

#card-gallery .asset .delete,
#card-gallery .asset .cover {
    position: absolute;
    top: -10px;
    visibility: hidden;
    text-shadow: 1px 1px 0 white,
                 0 1px 0 white,
                 1px 0 0 white,
                 1px -1px 0 white,
                 -1px 1px 0 white;
}

#card-gallery .asset:hover .delete,
#card-gallery .asset:hover .cover {
    visibility: visible;
}

#card-gallery .asset .delete {
    left: -4px;
}

#card-gallery .asset .cover {
    right: -8px;
}

.cover img {
    border: 4px solid white;
    box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.24);
}
/* End card gallery */

/* Card description */

.description li {
    list-style: inherit;
}

.description ul ul {
    list-style-type: circle;
}

/* End card description */

/* End cards */

/* Board view switch zone (calendar / columns / search) */
#switch_zone .btn {
    font-size: 16px;
}

#search {
    -webkit-border-radius: 5px;
    -moz-border-radius: 5px;
    border-radius: 5px;
}

#search:focus, #search.highlight input {
    border-color: rgba(230, 163, 35, 0.8);
    outline: 0;
    outline: thin dotted \9;
}

#search.nomatches input {
    border-color: red;
}

#show_results {
    font-size: 18px;
    color: #e6a323;
}

span.nomatches {
    color: red;
}

/* End board view switch zone (calendar / columns / search) */

/* History */
#action-log select:first-child {
    width: calc(33.33% - 1em);
}

#action-log select:last-child {
    width: 66.66%;
}

div.history {
    font-size: 12px;
}

div.history th {
    font-size: 12px;
}

/* End history */

/* Progress bar */
.progress {
    border: 1px solid #c0c0c0;
}

.progress .bar {
    background-color: #c0c0c0;
}
/* End progress bar */

/* Checklists */
.checklists .checklist {
    border-radius: 5px;
    border: 1px solid #c0c0c0
}

.checklists .checklist i[class^="icon-checkbox-"] {
    font-size: 16px;
}
/* Checklists end */

/* Calendar */
.calendar {
    background: white;
    border: 1px solid #c0c0c0;
}

.calendar .calendar-content table th {
    color: #737373
}

.calendar .calendar-content table tr td a {
    color: #737373
}

.calendar .calendar-content table tr td.active a {
    font-weight: bold;
    background: #eaeaea;
    border: 1px solid #EAEAEA;
}

.calendar .calendar-content table tr td.today a {
    color: inherit;
    font-weight: bold;
}

.calendar .calendar-content table tr th.week_number,
.calendar .calendar-content table tr td.week_number {
    color: inherit;
    background-color: #eaeaea;
    font-weight: bold;
    border-right: solid 1px lightgrey;
}

.calendar .calendar-header select {
    font-size: 12px;
    font-weight: bold;
    border: 1px solid #eaeaea;
}
/* End calendar */

/* Weights */
.actionWeight select {
    border: none;
    outline: none;
    background-color: transparent;
}
/* End weights */

/* Nb items */
.nbItems .label {
    background: none;
    color: #c0c0c0;
    font: 14px OpenSansSemibold
}
/* End nb items */

/* Responsive */
@media (max-width: 813px) {
    .row > .list {
        background-color: #eaeaea;
    }

    .board .board-title {
        font-size: 25px
    }

}

@media all and (max-width: 640px) {
    .nav-menu #mainActions {
        background: white;
        color: #434343;
        font-size: 14px;
        border-radius: 0 0 10px 0;
    }

    .board .board-title {
        font-size: 18px;
    }

    .board .board-title .title-form {
        font-size: 16px;
    }
}
